﻿#region Using Statements
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using System;
#endregion

namespace RhinoXNA.RhinoGraphics.Rhino2D.RhinoHUD
{
    /// <summary>
    /// Stores a list of all HUD elements
    /// </summary>
    public sealed class RhinoHUDManager
    {
        #region Private Variables
        // Singleton stuff
        private static RhinoHUDManager _instance;
        private static object syncRoot = new Object();

        // Stored list of entities
        private List<IRhinoGraphicsComponent> _entities;
        #endregion

        #region Public Properties
        /// <summary>
        /// Returns the list of stored HUD entities
        /// </summary>
        public List<IRhinoGraphicsComponent> Entities { get { return _entities; } }

        /// <summary>
        /// Returns the global instance of a RhinoHUDManager
        /// </summary>
        public static RhinoHUDManager Instance
        {
            get
            {
                if (_instance == null)
                {
                    lock (syncRoot)
                    {
                        if (_instance == null)
                        {
                            _instance = new RhinoHUDManager();
                        }
                    }
                }

                return _instance;
            }
        }
        #endregion

        #region Private Methods
        /// <summary>
        /// Creates a new RhinoHUDManager
        /// </summary>
        private RhinoHUDManager()
        {
            _entities = new List<IRhinoGraphicsComponent>();
        }
        #endregion

        #region Pubic Methods
        /// <summary>
        /// Adds an entity to the list of Hud entities
        /// </summary>
        /// <param name="entity">Entity to store</param>
        public void AddEntity(IRhinoGraphicsComponent entity)
        {
            _entities.Add(entity);
        }

        /// <summary>
        /// Removes all entities from the stored entities list
        /// </summary>
        public void Clear()
        {
            _entities.Clear();
        }

        /// <summary>
        /// Adds the list of entities to the stored entity list
        /// </summary>
        /// <param name="entities">Entities to store</param>
        public void AddEntities(List<IRhinoGraphicsComponent> entities)
        {
            foreach (IRhinoGraphicsComponent entity in entities)
            {
                _entities.Add(entity);
            }
        }

        /// <summary>
        /// Removes all entities with the given handle (name)
        /// </summary>
        /// <param name="entityHandle">Handle of the entity to remove</param>
        public void RemoveEntity(String entityHandle)
        {
            _entities.RemoveAll(delegate(IRhinoGraphicsComponent ir) { return ir.Handle == entityHandle; });
        }
        #endregion
    }
}
