﻿#region Using Statements
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using System.Collections.Generic;
using Microsoft.Xna.Framework.Input;
using System;
using RhinoXNA.RhinoGraphics.Rhino2D.RhinoHUD;
using RhinoXNA.RhinoGraphics.Rhino2D;
using RhinoXNA.RhinoUtilities;
#endregion

namespace RhinoXNA.RhinoGameObjects
{
    /// <summary>
    /// Abstract class to provide similar Level functionality
    /// </summary>
    public abstract class RhinoLevel
    {
        #region Protected Variables
        protected InputBinding _inputBinding;
        #endregion

        #region Public Methods
        /// <summary>
        /// Creates a new instance of this type
        /// </summary>
        public RhinoLevel()
        {
            
        }

        /// <summary>
        /// Updates all entities and level objects
        /// </summary>
        /// <param name="gameTime">Current gametime</param>
        public void Update(GameTime gameTime)
        {
            for (int i = 0; i < RhinoEntityManager.Instance.Entities.Count; i++ )
            {
                RhinoEntityManager.Instance.Entities[i].Update(gameTime);
            }

            UpdateImpl(gameTime);

            for (int i = 0; i < RhinoHUDManager.Instance.Entities.Count; i++)
            {
                RhinoHUDManager.Instance.Entities[i].Update(gameTime);
            }
        }

        /// <summary>
        /// Renders all stored entities and other level data
        /// </summary>
        public void Render()
        {
            foreach (IRhinoGraphicsComponent entity in RhinoEntityManager.Instance.Entities)
            {
                entity.Render();
            }

            RenderImpl();

            foreach (IRhinoGraphicsComponent entity in RhinoHUDManager.Instance.Entities)
            {
                entity.Render();
            }
        }
        #endregion

        #region Protected Methods
        /// <summary>
        /// Provides inheriting classes with differing render implementations
        /// </summary>
        protected abstract void RenderImpl();

        /// <summary>
        /// Provides inheriting classes with differing updateimplementations
        /// </summary>
        protected abstract void UpdateImpl(GameTime gameTime);
        #endregion
    }
}
