﻿#region Using Statements
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using System;
using System.Collections.Generic;
using RhinoXNA.RhinoUtilities;
#endregion

namespace RhinoXNA.RhinoGraphics.Rhino2D
{
    /// <summary>
    /// Provides common font functionality
    /// </summary>
    public class FontEntity : IRhinoDrawable
    {
        #region Protected Variables
        protected SpriteFont _font;
        protected string _text;
        #endregion

        #region Public Methods
        /// <summary>
        /// Creates a new instance of this class
        /// </summary>
        /// <param name="parameters">Parameters to define the new object</param>
        public FontEntity(List<String> parameters)
            :base()
        {
            _font = RhinoXNAAdapter.Instance.ContentManager.Load<SpriteFont>(parameters[1]);
            _text = parameters[3];

            bool vis = false;
            if (parameters[10].ToLower() == "true")
                vis = true;
            
            this.Position = RhinoLoader.GetPosition(parameters[4], parameters[5]);
            this.Rotation = MathHelper.ToRadians(Convert.ToInt32(parameters[6]));
            this.Scale = new Vector2(float.Parse(parameters[7]), float.Parse(parameters[8]));
            this.Layer = float.Parse(parameters[9]);
            this.isVisible = vis;
            this.Handle = parameters[2];
        }

        /// <summary>
        /// Updates the font (does nothing)
        /// </summary>
        /// <param name="gameTime">Current gametime</param>
        public override void Update(GameTime gameTime)
        {
        
        }

        /// <summary>
        /// Renders the font
        /// </summary>
        public override void Render()
        {
            SpriteBatch batch = RhinoXNAAdapter.Instance.SpriteBatch;
            batch.Begin();
            // Find the center of the string
            Vector2 FontOrigin = _font.MeasureString(_text) / 2;
            // Draw the string
            batch.DrawString(_font, _text, this.Position, Color.White,
                this.Rotation, FontOrigin, this.Scale, SpriteEffects.None, this.Layer);
            batch.End();
        }
        #endregion

    }
}
