﻿#region Using Statements
using System;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Graphics;
using RhinoXNA.RhinoGraphics.Rhino2D;
using System.Collections.Generic;
#endregion

namespace RhinoXNA.RhinoGraphics.Rhino2D
{
    /// <summary>
    /// Abstract class to provide common functionality between menu items
    /// </summary>
    public abstract class IMenuItem : IRhinoDrawable
    {
        protected SpriteEntity _sprite;
        protected FontEntity _font;

        public SpriteEntity Sprite
        {
            get { return _sprite; }
        }

        public FontEntity Font
        {
            get { return _font; }
        }

        public IMenuItem(List<String> parameters)
            : base()
        {
            
        }

        #region IDrawable Members
        public override void Update(GameTime gameTime)
        {
            Animate(gameTime);

            if (_sprite != null)
            {
                _sprite.Update(gameTime);
            }

            if (_font != null)
            {
                _font.Update(gameTime);
            }
        }

        public override void Render()
        {
            if (_sprite != null)
            {
                _sprite.Render();
            }

            if (_font != null)
            {
                _font.Render();
            }
        }
        #endregion

        protected abstract void Animate(GameTime gameTime);
    }
}
