﻿#region Using Statements
using Microsoft.Xna.Framework.Input;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
#endregion

namespace RhinoXNA.RhinoUtilities
{
    /// <summary>
    /// Utility class to store simple control states
    /// </summary>
    public class InputBinding
    {
        #region Private Variables
        private KeyboardState _oldBoardState;
        private MouseState _oldMouseState;
        private List<GamePadState> _oldControllerStates;
        #endregion

        #region Public Methods
        /// <summary>
        /// Creates a new InputBinding
        /// </summary>
        /// <param name="keyboard">Current Keyboard State</param>
        /// <param name="mouse">Current Mouse State</param>
        public InputBinding(KeyboardState keyboard, MouseState mouse)
        {
            _oldBoardState = keyboard;
            _oldMouseState = mouse;
            _oldControllerStates = new List<GamePadState>();
        }

        /// <summary>
        /// Creates a new Input Binding
        /// </summary>
        /// <param name="keyboard">Current keyboard state</param>
        /// <param name="mouse">Current mouse state</param>
        /// <param name="controllers">Current controller states</param>
        public InputBinding(KeyboardState keyboard, MouseState mouse, List<GamePadState> controllers)
        {
            _oldBoardState = keyboard;
            _oldMouseState = mouse;
            _oldControllerStates = controllers;
        }

        /// <summary>
        /// Updates the control states
        /// </summary>
        public void Update()
        {
            _oldBoardState = Keyboard.GetState();

            _oldMouseState = Mouse.GetState();

            for( PlayerIndex index = PlayerIndex.One; index <= PlayerIndex.Four; index++)
            {
                int i = 1;

                switch(index)
                {
                    case PlayerIndex.One:
                        break;
                    case PlayerIndex.Two:
                        i = 2;
                        break;
                    case PlayerIndex.Three:
                        i = 3;
                        break;
                    case PlayerIndex.Four:
                        i = 4;
                        break;
                }
                if (i < _oldControllerStates.Count)
                {
                    _oldControllerStates[i] = GamePad.GetState(index);
                }
            }
        }

        /// <summary>
        /// Checks to see if a key has recently been pressed once
        /// </summary>
        /// <param name="keyboard">Current keyboard state</param>
        /// <param name="key">Key to check</param>
        /// <returns>Returns true if key has recently been pressed</returns>
        public bool CheckKeyDown(KeyboardState keyboard, Keys key)
        {
            if (keyboard.IsKeyDown(key) && !_oldBoardState.IsKeyDown(key))
            {
                return true;
            }

            return false;
        }

        /// <summary>
        /// Checks to see if a key has recently been released once
        /// </summary>
        /// <param name="keyboard">Current keyboard state</param>
        /// <param name="key">Key to check</param>
        /// <returns>Returns true if the key has recently been pressed</returns>
        public bool CheckKeyUp(KeyboardState keyboard, Keys key)
        {
            if (keyboard.IsKeyUp(key) && !_oldBoardState.IsKeyUp(key))
            {
                return true;
            }

            return false;
        }
        #endregion
    }
}
